.. include:: ../BADGES.rst

.. _hspfbintoolbox_documentation:

hspfbintoolbox
==============

This is the home page for `hspfbintoolbox`.  The `hspfbintoolbox` is a
command line program and Python library functions to extract data out of
Hydrological Simulation Program - FORTRAN (HSPF) binary output files.

Should work with Python 3.6+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   command_line
   function_summary
   contributing
   authors
   license

Other Projects
--------------
http://timcera.bitbucket.io
